@@ -15,6 +15,10 @@ struct UserpicsRow;
 
 class ChannelData;
 
+namespace Data {
+struct UniqueGift;
+} // namespace Data
+
 namespace Main {
 class Session;
 } // namespace Main
@@ -72,3 +76,8 @@ enum class UserpicsTransferType {
 	rpl::producer<std::vector<not_null<PeerData*>>> peers,
 	const style::UserpicsRow &st,
 	int limit);
+
+[[nodiscard]] object_ptr<Ui::RpWidget> CreateGiftTransfer(
+	not_null<Ui::RpWidget*> parent,
+	std::shared_ptr<Data::UniqueGift> unique,
+	not_null<PeerData*> to);
