@@ -138,6 +138,8 @@ enum class GiftType : uchar {
 	Credits, // count - credits
 	Ton, // count - nano tons
 	StarGift, // count - stars
+	ChatTheme,
+	BirthdaySuggest,
 };
 
 struct GiftCode {
@@ -150,17 +152,20 @@ struct GiftCode {
 	ChannelData *channel = nullptr;
 	PeerData *channelFrom = nullptr;
 	uint64 channelSavedId = 0;
+	QString giftPrepayUpgradeHash;
 	MsgId giveawayMsgId = 0;
-	MsgId upgradeMsgId = 0;
+	MsgId realGiftMsgId = 0;
 	int starsConverted = 0;
 	int starsToUpgrade = 0;
 	int starsUpgradedBySender = 0;
+	int starsForDetailsRemove = 0;
 	int limitedCount = 0;
 	int limitedLeft = 0;
 	int64 count = 0;
 	GiftType type = GiftType::Premium;
 	bool viaGiveaway : 1 = false;
 	bool transferred : 1 = false;
+	bool upgradeSeparate : 1 = false;
 	bool upgradable : 1 = false;
 	bool unclaimed : 1 = false;
 	bool anonymous : 1 = false;
@@ -203,6 +208,7 @@ public:
 	virtual bool paperForBoth() const;
 	virtual FullStoryId storyId() const;
 	virtual bool storyExpired(bool revalidate = false);
+	virtual bool storyUnsupported() const;
 	virtual bool storyMention() const;
 	virtual const GiveawayStart *giveawayStart() const;
 	virtual const GiveawayResults *giveawayResults() const;
@@ -750,6 +756,7 @@ public:
 
 	FullStoryId storyId() const override;
 	bool storyExpired(bool revalidate = false) override;
+	bool storyUnsupported() const override;
 	bool storyMention() const override;
 
 	TextWithEntities notificationText() const override;
@@ -771,6 +778,7 @@ private:
 	const FullStoryId _storyId;
 	const bool _mention = false;
 	bool _viewMayExist = false;
+	bool _unsupported = false;
 	bool _expired = false;
 
 };
