@@ -320,20 +320,20 @@ void SettingsWidget::addLocationLabel(
 }
 
 void SettingsWidget::chooseFormat() {
-	const auto shared = std::make_shared<QPointer<Ui::GenericBox>>();
+	const auto shared = std::make_shared<base::weak_qptr<Ui::GenericBox>>();
 	const auto callback = [=](Format format) {
 		changeData([&](Settings &data) {
 			data.format = format;
 		});
-		if (const auto weak = shared->data()) {
-			weak->closeBox();
+		if (const auto strong = shared->get()) {
+			strong->closeBox();
 		}
 	};
 	auto box = Box(
 		ChooseFormatBox,
 		readData().format,
 		callback);
-	*shared = Ui::MakeWeak(box.data());
+	*shared = base::make_weak(box.data());
 	_showBoxCallback(std::move(box));
 }
 
@@ -602,18 +602,18 @@ void SettingsWidget::editDateLimit(
 		? base::unixtime::parse(min).date()
 		: QDate::currentDate();
 	const auto month = highlighted;
-	const auto shared = std::make_shared<QPointer<Ui::CalendarBox>>();
+	const auto shared = std::make_shared<base::weak_qptr<Ui::CalendarBox>>();
 	const auto finalize = [=](not_null<Ui::CalendarBox*> box) {
 		box->addLeftButton(std::move(resetLabel), crl::guard(this, [=] {
 			done(0);
-			if (const auto weak = shared->data()) {
+			if (const auto weak = shared->get()) {
 				weak->closeBox();
 			}
 		}));
 	};
 	const auto callback = crl::guard(this, [=](const QDate &date) {
 		done(base::unixtime::serialize(date.startOfDay()));
-		if (const auto weak = shared->data()) {
+		if (const auto weak = shared->get()) {
 			weak->closeBox();
 		}
 	});
@@ -630,7 +630,7 @@ void SettingsWidget::editDateLimit(
 			? base::unixtime::parse(max).date()
 			: QDate::currentDate()),
 	});
-	*shared = Ui::MakeWeak(box.data());
+	*shared = base::make_weak(box.data());
 	_showBoxCallback(std::move(box));
 }
 
