@@ -179,6 +179,7 @@ struct InvoiceStarGift {
 	TextWithEntities message;
 	not_null<PeerData*> recipient;
 	int limitedCount = 0;
+	int perUserLimit = 0;
 	bool anonymous = false;
 	bool upgraded = false;
 };
@@ -202,6 +203,7 @@ struct CreditsFormData {
 	InvoiceCredits invoice;
 	MTPInputInvoice inputInvoice;
 	int starGiftLimitedCount = 0;
+	int starGiftPerUserLimit = 0;
 	bool starGiftForm = false;
 };
 
