@@ -176,19 +176,13 @@ void ShowPaidReactionDetails(
 
 	auto submitText = [=](rpl::producer<int> amount) {
 		auto nice = std::move(amount) | rpl::map([=](int count) {
-			return Ui::CreditsEmojiSmall(session).append(
+			return Ui::CreditsEmojiSmall().append(
 				Lang::FormatCountDecimal(count));
 		});
 		return tr::lng_paid_react_send(
 			lt_price,
 			std::move(nice),
-			Ui::Text::RichLangValue
-		) | rpl::map([=](TextWithEntities &&text) {
-			return Ui::TextWithContext{
-				.text = std::move(text),
-				.context = Core::TextContext({ .session = session }),
-			};
-		});
+			Ui::Text::RichLangValue);
 	};
 	auto top = std::vector<Ui::PaidReactionTop>();
 	const auto add = [&](const Data::MessageReactionsTopPaid &entry) {
