@@ -621,11 +621,8 @@ rpl::producer<bool> Checkbox::checkedValue() const {
 }
 
 void Checkbox::resizeToText() {
-	if (_st.width <= 0) {
-		resizeToWidth(_text.maxWidth() - _st.width);
-	} else {
-		resizeToWidth(_st.width);
-	}
+	updateNaturalWidth();
+	resizeToWidth(width(), true);
 }
 
 void Checkbox::setChecked(bool checked, NotifyAboutChange notify) {
@@ -641,15 +638,17 @@ void Checkbox::finishAnimating() {
 	_check->finishAnimating();
 }
 
-int Checkbox::naturalWidth() const {
-	if (_st.width > 0) {
-		return _st.width;
-	}
-	auto result = _st.checkPosition.x() + _check->getSize().width();
-	if (!_text.isEmpty()) {
-		result += _st.textPosition.x() + _text.maxWidth();
-	}
-	return result - _st.width;
+void Checkbox::updateNaturalWidth() {
+	setNaturalWidth([&] {
+		if (_st.width > 0) {
+			return _st.width;
+		}
+		auto result = _st.checkPosition.x() + _check->getSize().width();
+		if (!_text.isEmpty()) {
+			result += _st.textPosition.x() + _text.maxWidth();
+		}
+		return result - _st.width;
+	}());
 }
 
 void Checkbox::paintEvent(QPaintEvent *e) {
